// Package clog provides basic logging utilities.
package clog

import (
	"fmt"
	"os"
)

func logs(str string, keyvals []any) {
	fmt.Fprint(os.Stderr, str)
	if len(keyvals) != 0 {
		fmt.Fprint(os.Stderr, " ")
		for i, j := range keyvals {
			if i&1 == 0 {
				fmt.Fprintf(os.Stderr, "%v=", j)
			} else if i == len(keyvals)-1 {
				fmt.Fprintf(os.Stderr, "%#v", j)
			} else {
				fmt.Fprintf(os.Stderr, "%#v ", j)
			}
		}
	}
	fmt.Fprintln(os.Stderr, "\x1b[0m")
}

func Errors(str string, keyvals ...any) {
	logs("\x1b[1;91mERROR: "+str, keyvals)
}

func Warns(str string, keyvals ...any) {
	logs("\x1b[1;93mWARNING: "+str, keyvals)
}

func Debugs(str string, keyvals ...any) {
	logs("\x1b[90mDEBUG: "+str, keyvals)
}

func Infos(str string, keyvals ...any) {
	logs("\x1b[0mINFO: "+str, keyvals)
}

func Fatals(exit int, str string, keyvals ...any) {
	logs("\x1b[1;35mFATAL: "+str, keyvals)
	os.Exit(exit)
}

func log(str string) {
	fmt.Fprint(os.Stderr, str)
	fmt.Fprintln(os.Stderr, "\x1b[0m")
}

func Error(str string) {
	log("\x1b[1;91mERROR: "+str)
}

func Warn(str string) {
	log("\x1b[1;93mWARNING: "+str)
}

func Debug(str string) {
	log("\x1b[90mDEBUG: "+str)
}

func Info(str string) {
	log("\x1b[0mINFO: "+str)
}

func Fatal(exit int, str string) {
	log("\x1b[1;35mFATAL: "+str)
	os.Exit(exit)
}
